@@ -24,14 +24,14 @@ namespace cul = com::ubuntu::location;
 TEST(Position, AllFieldsAreInvalidForDefaultConstructor)
 {
     cul::Position p;
-    EXPECT_FALSE(p.altitude);
-    EXPECT_FALSE(p.accuracy.vertical);
+    EXPECT_FALSE(static_cast<bool>(p.altitude));
+    EXPECT_FALSE(static_cast<bool>(p.accuracy.vertical));
 }
 
 TEST(Position, InitWithLatLonGivesValidFieldsForLatLon)
 {
     cul::Position p{cul::wgs84::Latitude{}, cul::wgs84::Longitude{}};
-    EXPECT_FALSE(p.altitude);
+    EXPECT_FALSE(static_cast<bool>(p.altitude));
 }
 
 TEST(Position, InitWithLatLonAltGivesValidFieldsForLatLonAlt)
@@ -40,7 +40,7 @@ TEST(Position, InitWithLatLonAltGivesValidFieldsForLatLonAlt)
         cul::wgs84::Latitude{},
         cul::wgs84::Longitude{},
         cul::wgs84::Altitude{}};
-    EXPECT_TRUE(p.altitude);
+    EXPECT_TRUE(static_cast<bool>(p.altitude));
 }
 
 #include <com/ubuntu/location/codec.h>
